@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_dump_data_sql.c 59 2006-09-16 12:23:27Z julien $
+ * $Id: cl_dump_data_sql.c 68 2010-11-27 10:20:15Z julien $
  */
 
 #include <stdio.h>
@@ -38,11 +38,11 @@ clarion_dump_field_string_sql (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, c
   buf[clfd->length] = '\0';
   clarion_trim(buf, clfd->length);
 
-  if (strlen(buf) > 0)
+  if (strlen((char *)buf) > 0)
     {
       if (charset != NULL)
 	{
-	  utf = clarion_iconv(charset, buf);
+	  utf = clarion_iconv(charset, (char *)buf);
 
 	  if (utf != NULL)
 	    {
@@ -91,7 +91,7 @@ clarion_dump_memo_entry_sql (ClarionRecordHeader *clrh, FILE *fp, char *charset)
       {
 	clarion_trim(clme.memo, 252);
 
-	clarion_singlespace(clme.memo);
+	clarion_singlespace((char *)clme.memo);
 
 	/* Sanitize the \r\n mess */
 	for (i = 0, j = 0; clme.memo[i] != '\0'; i++, j++)
@@ -230,11 +230,8 @@ clarion_dump_data_sql (ClarionHandle *cl)
 		clarion_dump_field_real(buf, &clfd[nflds], cl->data, "NULL");
 		break;
 	      case CL_FIELD_STRING:
-		clarion_dump_field_string_sql(buf, &clfd[nflds], cl->data, cl->charset);
-		break;
 	      case CL_FIELD_STRING_PIC_TOK:
-		/* FIXME: unimplemented */
-		clarion_dump_field_stringpictok(buf, &clfd[nflds], cl->data, "NULL");
+		clarion_dump_field_string_sql(buf, &clfd[nflds], cl->data, cl->charset);
 		break;
 	      case CL_FIELD_BYTE:
 		clarion_dump_field_byte(buf, &clfd[nflds], cl->data, "NULL");
