@@ -17,7 +17,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_dump_field.c 59 2006-09-16 12:23:27Z julien $
+ * $Id: cl_dump_field.c 69 2010-11-27 10:20:16Z julien $
  */
 
 #include <stdio.h>
@@ -34,6 +34,7 @@ clarion_dump_memo_entry (ClarionRecordHeader *clrh, FILE *fp, char *plchold, cha
 {
   ClarionMemoEntry clme;
   char *utf;
+  uint32_t curblk;
 
   if ((clrh->rhd & CL_RECORD_DELETED) || (clrh->rptr == 0))
     {
@@ -45,6 +46,7 @@ clarion_dump_memo_entry (ClarionRecordHeader *clrh, FILE *fp, char *plchold, cha
 
   fseek(fp, (((clrh->rptr - 1) * 256) + 6), SEEK_SET);
 
+  curblk = clrh->rptr - 1;
   do {
     fread(&clme.nxtblk, 4, 1, fp);
     fread(&clme.memo, 1, 252, fp);
@@ -56,7 +58,7 @@ clarion_dump_memo_entry (ClarionRecordHeader *clrh, FILE *fp, char *plchold, cha
 
     if (charset != NULL)
       {
-	utf = clarion_iconv(charset, clme.memo);
+	utf = clarion_iconv(charset, (char *)clme.memo);
 
 	if (utf != NULL)
 	  {
@@ -71,8 +73,14 @@ clarion_dump_memo_entry (ClarionRecordHeader *clrh, FILE *fp, char *plchold, cha
 
     if (clme.nxtblk == 0)
       break;
-    else
-      fseek(fp, ((clme.nxtblk * 256) + 6), SEEK_SET);
+    else if (clme.nxtblk == curblk)
+      {
+	fprintf(stderr, "Memo entry %08x looping back to itself\n", curblk);
+	break;
+      }
+
+    fseek(fp, ((clme.nxtblk * 256) + 6), SEEK_SET);
+    curblk = clme.nxtblk;
   } while (1);
 
   fflush(stdout);
@@ -131,11 +139,11 @@ clarion_dump_field_string (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char
   buf[clfd->length] = '\0';
   clarion_trim(buf, clfd->length);
 
-  if (strlen(buf) > 0)
+  if (strlen((char *)buf) > 0)
     {
       if (charset != NULL)
 	{
-	  utf = clarion_iconv(charset, buf);
+	  utf = clarion_iconv(charset, (char *)buf);
 
 	  if (utf != NULL)
 	    {
@@ -154,13 +162,6 @@ clarion_dump_field_string (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char
   fflush(stdout);
 }
 
-void
-clarion_dump_field_stringpictok (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *plchold)
-{
-  /* FIXME: unimplemented */
-  fseek(fp, clfd->length, SEEK_CUR);
-}
-
 void
 clarion_dump_field_byte (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *plchold)
 {
