@@ -1,7 +1,7 @@
 /*
  * cldump - Dumps Clarion databases to text, SQL and CSV formats
  *
- * Copyright (C) 2004-2006 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2004-2006,2010 Julien BLACHE <jb@jblache.org>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_dump_meta.c 60 2006-09-16 13:19:51Z julien $
+ * $Id: cl_dump_meta.c 65 2010-11-27 10:20:08Z julien $
  */
 
 #include <stdio.h>
@@ -164,20 +164,16 @@ clarion_dump_header (ClarionHeader *clh)
 static void
 clarion_dump_pic_desc (ClarionPicDesc *clpd)
 {
-  int i, j;
+  int i;
 
   fprintf(stderr, "  === PICTURE DESCRIPTOR ===\n\n");
   fprintf(stderr, "\tpiclen : 0x%04x\n", clpd->piclen);
-  fprintf(stderr, "\tpicstr :\n");
-  for (i = 0; i < 16; i++)
+  fprintf(stderr, "\tpicstr : [%s]", clpd->picstr);
+  for (i = 0; i < clpd->piclen; i++)
     {
-      fprintf(stderr, "\t       ");
-      for (j = 0; j < 16; j++)
-	{
-	  fprintf(stderr, " 0x%02x", clpd->picstr[(i * 16) + j]);
-	}
-      fprintf(stderr, "\n");
+      fprintf(stderr, " 0x%02x", clpd->picstr[i]);
     }
+  fprintf(stderr, "\n");
 
   fflush(stderr);
 }
@@ -206,7 +202,7 @@ clarion_dump_arr_desc (ClarionArrDesc *clad, int nbarrs)
 }
 
 static void
-clarion_dump_field_desc(ClarionFieldDesc *clfd, uint16_t numflds)
+clarion_dump_field_desc(ClarionFieldDesc *clfd, uint16_t numflds, ClarionPicDesc *clpd)
 {
   int i, j;
   char *fldtype[9] = {
@@ -244,7 +240,7 @@ clarion_dump_field_desc(ClarionFieldDesc *clfd, uint16_t numflds)
       fprintf(stderr, "picnum  : 0x%04x\n", clfd[i].picnum);
 
       if (clfd[i].picnum != 0)
-	clarion_dump_pic_desc(clfd[i].pic);
+	clarion_dump_pic_desc(clpd + (clfd[i].picnum - 1));
 
       fprintf(stderr, "\n");
     }
@@ -347,6 +343,6 @@ clarion_dump_meta (ClarionHandle *cl)
 void
 clarion_dump_schema (ClarionHandle *cl)
 {
-  clarion_dump_field_desc(cl->clm.clfd, cl->clm.clh->numflds);
+  clarion_dump_field_desc(cl->clm.clfd, cl->clm.clh->numflds, cl->clm.clp);
   clarion_dump_key_desc(cl->clm.clk, cl->clm.clfd, cl->clm.clh->numbkeys);
 }
