@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_dump_meta_csv.c 59 2006-09-16 12:23:27Z julien $
+ * $Id: cl_dump_meta_csv.c 68 2010-11-27 10:20:15Z julien $
  */
 
 #include <stdio.h>
@@ -53,9 +53,9 @@ clarion_dump_field_desc_csv(ClarionHandle *cl)
       if (i > 0)
 	fprintf(stdout, "%c", cl->fsep);
 
-      strncpy(buf, clfd[i].fldname, 17);
+      memcpy(buf, clfd[i].fldname, 17);
       clarion_trim(buf, 16);
-      pbuf = strchr(buf, ':');
+      pbuf = (uint8_t *)strchr((char *)buf, ':');
 
       fprintf(stdout, "%s", (pbuf != NULL) ? ++pbuf : buf);
     }
