@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_dump_meta_sql.c 60 2006-09-16 13:19:51Z julien $
+ * $Id: cl_dump_meta_sql.c 68 2010-11-27 10:20:15Z julien $
  */
 
 #include <stdio.h>
@@ -41,16 +41,16 @@ clarion_dump_field_desc_sql(ClarionHandle *cl)
 
   for (i = 0; i < cl->clm.clh->numflds; i++)
     {
-      strncpy(buf, clfd[i].fldname, 17);
+      memcpy(buf, clfd[i].fldname, 17);
       clarion_trim(buf, 16);
-      pbuf = strchr(buf, ':');
+      pbuf = (uint8_t *)strchr((char *)buf, ':');
 
       if (pbuf != NULL)
 	pbuf++;
       else
 	pbuf = buf;
 
-      for (j = 0; j < strlen(pbuf); j++)
+      for (j = 0; j < strlen((char *)pbuf); j++)
 	{
 	  pbuf[j] = tolower(pbuf[j]);
 	}
@@ -78,10 +78,9 @@ clarion_dump_field_desc_sql(ClarionHandle *cl)
 	    fprintf(stdout, "FLOAT"); /* should mean "double precision" to most RDBMS */
 	    break;
 	  case CL_FIELD_STRING:
+	  case CL_FIELD_STRING_PIC_TOK:
 	    fprintf(stdout, "VARCHAR(%d)", clfd[i].length);
 	    break;
-	  case CL_FIELD_STRING_PIC_TOK:
-	    break; /* FIXME: unimplemented */
 	  case CL_FIELD_BYTE:
 	    fprintf(stdout, "SMALLINT");
 	    break;
@@ -127,16 +126,16 @@ clarion_dump_key_desc_sql (ClarionHandle *cl, ClarionKeyDesc *clk, ClarionFieldD
 
   for (i = 0; i < numbkeys; i++)
     {
-      strncpy(buf, clk[i].keyname, 17);
+      memcpy(buf, clk[i].keyname, 17);
       clarion_trim(buf, 16);
-      pbuf = strchr(buf, ':');
+      pbuf = (uint8_t *)strchr((char *)buf, ':');
 
       if (pbuf != NULL)
 	pbuf++;
       else
 	pbuf = buf;
 
-      for (j = 0; j < strlen(pbuf); j++)
+      for (j = 0; j < strlen((char *)pbuf); j++)
 	{
 	  pbuf[j] = tolower(pbuf[j]);
 	}
@@ -169,16 +168,16 @@ clarion_dump_key_desc_sql (ClarionHandle *cl, ClarionKeyDesc *clk, ClarionFieldD
 
 	  for (k = 0; k < numparts; k++)
 	    {
-	      strncpy(buf, clfd[clkp[k].fldnum - 1].fldname, 17);
+	      memcpy(buf, clfd[clkp[k].fldnum - 1].fldname, 17);
 	      clarion_trim(buf, 16);
-	      pbuf = strchr(buf, ':');
+	      pbuf = (uint8_t *)strchr((char *)buf, ':');
 
 	      if (pbuf != NULL)
 		pbuf++;
 	      else
 		pbuf = buf;
 
-	      for (l = 0; l < strlen(pbuf); l++)
+	      for (l = 0; l < strlen((char *)pbuf); l++)
 		{
 		  pbuf[l] = tolower(pbuf[l]);
 		}
