@@ -1,7 +1,7 @@
 /*
  * cldump - Dumps Clarion databases to text, SQL and CSV formats
  *
- * Copyright (C) 2004-2006 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2004-2006,2010 Julien BLACHE <jb@jblache.org>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cl_meta.c 60 2006-09-16 13:19:51Z julien $
+ * $Id: cl_meta.c 65 2010-11-27 10:20:08Z julien $
  */
 
 #include <stdio.h>
@@ -108,7 +108,6 @@ clarion_read_field_desc(ClarionHandle *cl)
       fread(&clfd[i].decdec, 1, 1, fp);
       fread(&clfd[i].arrnum, 2, 1, fp);
       fread(&clfd[i].picnum, 2, 1, fp);
-      clfd[i].pic = NULL;
       clfd[i].arr = NULL;
       clfd[i].nbarrs = 0;
     }
@@ -219,24 +218,35 @@ clarion_read_key_desc (ClarionHandle *cl)
   return 0;
 }
 
-void
+int
 clarion_read_pic_desc (ClarionHandle *cl)
 {
   int i;
-  int numflds = cl->clm.clh->numflds;
+  int numpics = cl->clm.clh->numpics;
   FILE *fp = cl->data;
-  ClarionFieldDesc *clfd = cl->clm.clfd;
+  ClarionPicDesc *clp;
 
-  for (i = 0; i < numflds; i++)
+  if (numpics == 0)
+    return 0;
+
+  clp = (ClarionPicDesc *) malloc(numpics * sizeof(ClarionPicDesc));
+
+  if (clp == NULL)
+    return -1;
+
+  for (i = 0; i < numpics; i++)
     {
-      if (clfd[i].picnum != 0)
-	{
-	  clfd[i].pic = (ClarionPicDesc *) malloc(sizeof(ClarionPicDesc));
-	  fread(&clfd[i].pic->piclen, 2, 1, fp);
-	  fread(&clfd[i].pic->picstr, 1, 256, fp);
-	  clfd[i].pic->picstr[clfd[i].pic->piclen] = '\0';
-	}
+      fread(&clp[i].piclen, 2, 1, fp);
+
+      clp[i].picstr = (uint8_t *) malloc(clp[i].piclen + 1);
+
+      fread(clp[i].picstr, 1, clp[i].piclen, fp);
+      clp[i].picstr[clp[i].piclen] = '\0';
     }
+
+  cl->clm.clp = clp;
+
+  return 0;
 }
 
 void
