@@ -1,7 +1,7 @@
 /*
  * cldump - Dumps Clarion databases to text, SQL and CSV formats
  *
- * Copyright (C) 2004-2006 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2004-2006,2010 Julien BLACHE <jb@jblache.org>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cldump.c 60 2006-09-16 13:19:51Z julien $
+ * $Id: cldump.c 66 2010-11-27 10:20:11Z julien $
  */
 
 #include <stdio.h>
@@ -89,6 +89,7 @@ void
 clarion_free_handle (ClarionHandle *cl)
 {
   int i, j;
+  ClarionPicDesc *clp = cl->clm.clp;
   ClarionKeyDesc *clk = cl->clm.clk;
   ClarionFieldDesc *clfd = cl->clm.clfd;
 
@@ -104,11 +105,18 @@ clarion_free_handle (ClarionHandle *cl)
     }
   free(clk);
 
+  if (cl->clm.clh->numpics > 0)
+    {
+      for (i = 0; i < cl->clm.clh->numpics; i++)
+	{
+	  if (clp[i].picstr)
+	    free(clp[i].picstr);
+	}
+      free(clp);
+    }
+
   for (i = 0; i < cl->clm.clh->numflds; i++)
     {
-      if (clfd[i].pic != NULL)
-	free(clfd[i].pic);
-
       if (clfd[i].arr != NULL)
 	{
 	  for (j = 0; j < clfd[i].nbarrs; j++)
@@ -150,6 +158,7 @@ cl_usage(void)
   fprintf(stdout, "   -n/--no-memo            Do not dump memo entries\n");
   fprintf(stdout, "   -U[charset]            Convert strings from charset to UTF-8\n");
   fprintf(stdout, "     --utf8[=charset]        Default charset: iso8859-1\n");
+  fprintf(stdout, "   -x/--decrypt            Decrypt database, key location 1-4\n");
   fprintf(stdout, "\n");
   fprintf(stdout, "By default, cldump uses a human-friendly format to dump the database.\n");
   fprintf(stdout, "Options marked with a * are the default.\n");
@@ -160,7 +169,7 @@ void
 cl_version(void)
 {
   fprintf(stdout, "cldump v%s - Clarion database extractor\n", CL_VERSION);
-  fprintf(stdout, "Copyright (C) 2004-2006 Julien BLACHE <jb@jblache.org>\n");
+  fprintf(stdout, "Copyright (C) 2004-2006,2010 Julien BLACHE <jb@jblache.org>\n");
   fprintf(stdout, "This software is released under the terms of the GNU General Public License\n");
   fprintf(stdout, "version 2, as published by the Free Software Foundation.\n");
 }
@@ -185,6 +194,7 @@ main (int argc, char **argv)
     {"mysql", 0, NULL, 'M'},
     {"no-memo", 0, NULL, 'n'},
     {"utf8", 2, NULL, 'U'},
+    {"decrypt", 1, NULL, 'x'},
     {"help", 0, NULL, 'h'},
     {"version", 0, NULL, 'v'},
     {NULL, 0, NULL, 0}
@@ -197,13 +207,16 @@ main (int argc, char **argv)
   cl.sql_quote_begin = '"';
   cl.sql_quote_end = '"';
 
-  while ((clopt = getopt_long(argc, argv, "dmf:cSsMnU::hv", clargs, &cloptind)) != -1)
+  while ((clopt = getopt_long(argc, argv, "dDmf:cSsMnU::x:hv", clargs, &cloptind)) != -1)
     {
       switch (clopt)
 	{
 	  case 'd':
 	    cl.opts |= CL_OPT_DUMP_ACTIVE;
 	    break;
+	  case 'D':
+	    cl.opts |= CL_OPT_DUMP_DATA;
+	    break;
 	  case 'm':
 	    cl.opts |= CL_OPT_DUMP_META;
 	    break;
@@ -252,6 +265,17 @@ main (int argc, char **argv)
 	    else
 	      cl.charset = strdup("ISO8859-1");
 	    break;
+	  case 'x':
+	    cl.decmode = atoi(optarg);
+
+	    if ((cl.decmode < 1) || (cl.decmode > 4))
+	      {
+		fprintf(stderr, "cldump: Error: key location argument is 1-4.\n");
+		exit(1);
+	      }
+
+	    cl.opts |= CL_OPT_DECRYPT;
+	    break;
 	  case 'h':
 	    cl_version();
 	    fprintf(stdout, "\n");
@@ -319,6 +343,27 @@ main (int argc, char **argv)
       exit(2);
     }
 
+  if (cl.clm.clh->sfatr & CL_RECORDS_ENCRYPTED)
+    {
+      if (cl.opts & CL_OPT_DECRYPT)
+	{
+	  clarion_decrypt_all(&cl);
+
+	  /* NOT REACHED */
+	  exit(42);
+	}
+      else
+	{
+	  fprintf(stderr, "Database is encrypted, make backups and re-run with -x\n");
+	  exit(1);
+	}
+    }
+  else if (cl.opts & CL_OPT_DECRYPT)
+    {
+      fprintf(stderr, "Database is not encrypted; re-run without -x\n");
+      exit(0);
+    }
+
   if (!(cl.opts & CL_OPT_NO_MEMO))
     {
       ret = clarion_open_memo(&cl);
@@ -357,7 +402,16 @@ main (int argc, char **argv)
       exit(5);
     }
 
-  clarion_read_pic_desc(&cl);
+  ret = clarion_read_pic_desc(&cl);
+  if (ret != 0)
+    {
+      fclose(cl.data);
+      if (cl.memo != NULL)
+	fclose(cl.memo);
+      clarion_free_handle(&cl);
+      fprintf(stderr, "Couldn't read picture descriptors !\n");
+      exit(6);
+    }
 
   clarion_read_arr_desc(&cl);
 
