@@ -1,7 +1,7 @@
 /*
  * cldump - Dumps Clarion databases to text, SQL and CSV formats
  *
- * Copyright (C) 2004-2006 Julien BLACHE <jb@jblache.org>
+ * Copyright (C) 2004-2006,2010 Julien BLACHE <jb@jblache.org>
  *
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -16,13 +16,13 @@
  *    along with this program; if not, write to the Free Software
  *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: cldump.h 60 2006-09-16 13:19:51Z julien $
+ * $Id: cldump.h 70 2010-11-27 10:20:18Z julien $
  */
 
 #ifndef __CLDUMP_H__
 #define __CLDUMP_H__
 
-#define CL_VERSION               "0.10"
+#define CL_VERSION               "0.11"
 
 /* File signatures */
 #define CL_DATA_FILE_SIG         0x3343
@@ -75,8 +75,15 @@
 #define CL_OPT_SCHEMA            (1 << 5) /* output schema; combined with previous option, output SQL schema */
 #define CL_OPT_NO_MEMO           (1 << 6) /* do not output memo entries */
 #define CL_OPT_UTF8              (1 << 7) /* convert strings to UTF-8 */
+#define CL_OPT_DECRYPT           (1 << 8)
 #define CL_OPT_DEFAULT           (CL_OPT_DUMP_DATA | CL_OPT_DUMP_META | CL_OPT_SCHEMA) /* default: dump everything */
 
+/* Encryption key location */
+#define CL_KEY_NUMDELS_HI        1
+#define CL_KEY_RESERVED_HI       2
+#define CL_KEY_RESERVED_LO       3
+#define CL_KEY_RESERVED_MID      4
+
 
 typedef struct {
   uint16_t filesig;
@@ -106,7 +113,7 @@ typedef struct {
 
 typedef struct {
   uint16_t piclen;
-  uint8_t picstr[256+1];
+  uint8_t *picstr;
 } ClarionPicDesc;
 
 typedef struct {
@@ -130,7 +137,6 @@ typedef struct {
   uint8_t decdec;
   uint16_t arrnum;
   uint16_t picnum;
-  ClarionPicDesc *pic;
   ClarionArrDesc *arr;
   int nbarrs; /* this is not part of the Clarion database format */
 } ClarionFieldDesc;
@@ -156,11 +162,13 @@ typedef struct {
 typedef struct {
   ClarionHeader *clh;
   ClarionFieldDesc *clfd;
+  ClarionPicDesc *clp;
   ClarionKeyDesc *clk;
 } ClarionMeta;
 
 typedef struct {
-  unsigned char opts;
+  unsigned short opts;
+  unsigned char decmode;
   unsigned char fsep;
   unsigned char sql_quote_begin;
   unsigned char sql_quote_end;
@@ -188,6 +196,19 @@ typedef struct {
 } ClarionMemoEntry;
 
 
+/* In cldump.c */
+void
+clarion_free_handle (ClarionHandle *cl);
+
+int
+clarion_open_memo (ClarionHandle *cl);
+
+
+/* In cl_decrypt.c */
+void
+clarion_decrypt_all(ClarionHandle *cl);
+
+
 /* In cl_utils.c */
 #if BYTE_ORDER == BIG_ENDIAN
 size_t cl_fread (void *ptr, size_t size, size_t nmemb, FILE *stream);
@@ -214,7 +235,7 @@ clarion_read_field_desc(ClarionHandle *cl);
 int
 clarion_read_key_desc (ClarionHandle *cl);
 
-void
+int
 clarion_read_pic_desc (ClarionHandle *cl);
 
 void
@@ -252,9 +273,6 @@ clarion_dump_field_real (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *p
 void
 clarion_dump_field_string (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *plchold, char *charset);
 
-void
-clarion_dump_field_stringpictok (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *plchold);
-
 void
 clarion_dump_field_byte (uint8_t *buf, ClarionFieldDesc *clfd, FILE *fp, char *plchold);
 
